@@ -20,6 +20,8 @@
 
 class QTextCursor;
 class QTextEdit;
+class QTextDocument;
+class QWidget;
 
 namespace NoteShared
 {
@@ -29,6 +31,7 @@ public:
     NoteEditorUtils();
     void addCheckmark(QTextCursor &cursor);
     void insertDate(QTextEdit *editor);
+    void insertImage(QTextDocument *doc, QTextCursor &cursor, QTextEdit *par);
 };
 }
 #endif // NOTEEDITORUTILS_H
